@@ -1,5 +1,5 @@
 from __future__ import absolute_import, unicode_literals
-from xml.etree import ElementTree
+import xmltodict
 
 from .messages import MESSAGE_TYPES, UnknownMessage
 from .events import EVENT_TYPES
@@ -9,12 +9,12 @@ from .utils import to_text
 def parse_message(xml):
     if not xml:
         return
-    parser = ElementTree.fromstring(to_text(xml).encode('utf-8'))
-    message = dict((child.tag, to_text(child.text)) for child in parser)
+    message = xmltodict.parse(to_text(xml))['xml']
     message_type = message['MsgType'].lower()
     if message_type == 'event':
         event_type = message['Event'].lower()
-        if event_type == 'subscribe' and 'EventKey' in message:
+        if event_type == 'subscribe' and 'EventKey' in message and \
+                message['EventKey']:
             # Scan to subscribe with scene id event
             event_type = 'subscribe_scan'
             message['Event'] = event_type
